@@ -46,7 +46,7 @@ def create_sign(params, key, encoding=ALIPAY_INPUT_CHARSET, sign_type=ALIPAY_SIG
     assert sign_type in (ALIPAY_SIGN_TYPE_MD5, ALIPAY_SIGN_TYPE_RSA)
 
     s = _build_sign_body(params)
-    if sign_type is ALIPAY_SIGN_TYPE_RSA:
+    if sign_type == ALIPAY_SIGN_TYPE_RSA:
         signer = PKCS1_v1_5.new(key)
         signature = signer.sign(SHA1.new(s.encode(encoding)))
         return base64.encodebytes(signature).decode().replace("\n", "")
@@ -120,7 +120,7 @@ class AlipayClient(object):
         self.defaults = defaults
         self.defaults["goods_type"] = goods_type
 
-        if sign_type is ALIPAY_SIGN_TYPE_RSA:
+        if sign_type == ALIPAY_SIGN_TYPE_RSA:
             assert rsa_public_raw_key, 'rsa_public_raw_key is required'
             self.sign_key = RSA.importKey(key)
             self.rsa_public_key = RSA.importKey(rsa_public_raw_key)
@@ -179,7 +179,7 @@ class AlipayClient(object):
         assert isinstance(arguments, dict)
         assert arguments['sign_type'] == self.sign_type
 
-        if self.sign_type is ALIPAY_SIGN_TYPE_RSA:
+        if self.sign_type == ALIPAY_SIGN_TYPE_RSA:
             raw_content = _build_sign_body(arguments)
             key = self.rsa_public_key
             digest = SHA1.new()
