@@ -111,8 +111,9 @@ class AlipayCallbackView(View):
     def handle_alipay_callback(cls, data):
         result = None
         try:
-            seller_email = data['seller_email']
-            alipay_api = get_alipay_api(seller_email)
+            # seller_email = data['seller_email']  # seller email 可能带码
+            pid = data['pid']
+            alipay_api = get_alipay_api(pid=pid)
             result = alipay_api.client.get_verified_result(data)
             assert result.is_success != 'F', 'payment failed'
 
